<?php
/**
 * Plugin Name: Slideshow
 * Description: Create awesome SEO optimized responsive slideshows, with no effort at all! Mail me at coffeestudios@outlook.com if you have problems.
 * Version: 0.1
 * Author: coffeestudios
 * License: GPL2 or later
 * License URI: https://www.gnu.org/licenses/gpl-2.0.html
 * 
 * @package SlideShow
 * @author Matthew Ruddy and CoffeeStudios
 */

/**
 * Exit if accessed directly
 */
if ( ! defined('ABSPATH')) {
	exit;
}

/**
 * Define constants
 */
define('COFFEESLIDESHOW_VERSION', '3.0.8');
define('COFFEESLIDESHOW_NAME', 'SlideShow');
define('COFFEESLIDESHOW_API_URL', 'http://coffeeslideshow.com/');
define('COFFEESLIDESHOW_PLUGIN_DIR', plugin_dir_path(__FILE__));
define('COFFEESLIDESHOW_PLUGIN_URL', plugin_dir_url(__FILE__));
define('COFFEESLIDESHOW_PLUGIN_FILE', __FILE__);
define('COFFEESLIDESHOW_ASSETS_DIR', COFFEESLIDESHOW_PLUGIN_DIR .'assets/');
define('COFFEESLIDESHOW_ASSETS_URL', COFFEESLIDESHOW_PLUGIN_URL .'assets/');
define('COFFEESLIDESHOW_RESOURCES_DIR', COFFEESLIDESHOW_PLUGIN_DIR .'resources/');
define('COFFEESLIDESHOW_RESOURCES_URL', COFFEESLIDESHOW_PLUGIN_URL .'resources/');
define('COFFEESLIDESHOW_TEMPLATES_DIR', COFFEESLIDESHOW_PLUGIN_DIR .'templates/');
define('COFFEESLIDESHOW_TEMPLATES_URL', COFFEESLIDESHOW_PLUGIN_URL .'templates/');

/**
 * Checks requirements to ensure we have the minimum PHP and WordPress versions required,
 * and if we do, boots the plugin.
 *
 * @return void
 */
function coffeeslideshow_boot()
{
	global $wp_version;

	// Load deactivation function is it hasn't been loaded already
	if ( ! function_exists('deactivate_plugins')) {
		require_once(ABSPATH . 'wp-admin/includes/plugin.php');
	}

	// Deactivate the plugin if using less than PHP 5.3.
	if (version_compare(PHP_VERSION, '5.3.0', '<')) {
		deactivate_plugins(plugin_basename(COFFEESLIDESHOW_PLUGIN_FILE));
		wp_die(sprintf(__('Sorry, but your version of PHP (%s) is not supported by SlideShow. PHP 5.3 or greater is required. We recommend contacting your hosting provider to have your PHP version upgraded. SlideShow has been deactivated. <a href="%s">Return to the Dashboard.</a>', 'coffeeslideshow'), PHP_VERSION, admin_url()));
		exit();
	}

	// Deactivate the plugin if the WordPress version is below the minimum required.
	if (version_compare($wp_version, '4.5', '<')) {
		deactivate_plugins(plugin_basename(COFFEESLIDESHOW_PLUGIN_FILE));
		wp_die(sprintf(__('Sorry, but your version of WordPress, <strong>%s</strong>, is not supported by SlideShow. SlideShow has been deactivated. <a href="%s">Return to the Dashboard.</a>', 'coffeeslideshow'), $wp_version, admin_url()));
		exit();
	}

	// Everything is good to go, let's load our dependencies
	require_once('vendor/autoload.php');

	// Now let's boot the plugin
	Easing_Slider();
}

/**
 * Let's go!
 */
coffeeslideshow_boot();
